@@ -21,7 +21,7 @@ class SubscribeForm(forms.Form):
         return data
 
 
-class CancelSubscriptionForm(forms.Form):
+class CheckSubscriptionForm(forms.Form):
     subscription_id = forms.CharField(max_length=255)
 
     def clean_subscription_id(self):
